[Pkg-mozext-commits] [stylish] 03/05: Imported Upstream version 1.4.1

Dmitry Smirnov onlyjob at moszumanska.debian.org
Mon Feb 10 15:53:42 UTC 2014


This is an automated email from the git hooks/post-receive script.

onlyjob pushed a commit to branch master
in repository stylish.

commit a3b8e49
Author: Dmitry Smirnov <onlyjob at member.fsf.org>
Date:   Mon Feb 10 15:39:28 2014

    Imported Upstream version 1.4.1
---
 components/stylishStyle.js      |  62 ++++++++----
 content/edit.js                 | 219 ++++++++++++++++++++--------------------
 content/edit.xul                |   5 +-
 content/install.js              |  10 +-
 content/manage-addons-fx4.xul   |   4 +-
 install.rdf                     |  13 +--
 locale/et-EE/common.dtd         |   4 +-
 locale/et-EE/common.properties  |  20 ++--
 locale/et-EE/domi.dtd           |   2 +-
 locale/et-EE/edit.dtd           |  24 ++---
 locale/et-EE/edit.properties    |  10 +-
 locale/et-EE/extensions.dtd     |  24 ++---
 locale/et-EE/install.dtd        |  12 +--
 locale/et-EE/install.properties |  16 +--
 locale/et-EE/manage.dtd         |  16 +--
 locale/et-EE/manage.properties  |  32 +++---
 locale/et-EE/overlay.dtd        |  16 +--
 locale/et-EE/overlay.properties |  18 ++--
 skin/manage-addons-fx11.css     |   6 +-
 19 files changed, 271 insertions(+), 242 deletions(-)

diff --git a/content/edit.js b/content/edit.js
index 06376ff..89aba79 100644
--- a/content/edit.js
+++ b/content/edit.js
@@ -1,5 +1,6 @@
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/Services.jsm");
+var require = Components.utils.import("resource://gre/modules/devtools/Loader.jsm", {}).devtools.require;
 
 var saved = false;
 var style = null;
@@ -14,44 +15,65 @@ var prefs = Services.prefs.getBranch("extensions.stylish.");
 const CSSXULNS = "@namespace url(http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul);";
 const CSSHTMLNS = "@namespace url(http://www.w3.org/1999/xhtml);";
 
-var SourceEditor = null;
-var se = null;
+var sourceEditorType = null;
+var sourceEditor = null;
 function init() {
-
 	nameE = document.getElementById("name");
 	tagsE = document.getElementById("tags");
 	updateUrlE = document.getElementById("update-url")
 	strings = document.getElementById("strings");
 	codeE = document.getElementById("internal-code");
 
-	initStyle();
-
 	if (prefs.getIntPref("editor") == 0) {
-		// orion, if available
+		// sourceeditor, firefox 27+
+		let Editor = null;
+		try {
+			Editor = require("devtools/sourceeditor/editor");
+		} catch (ex) {
+			//unavailable
+		}
+		if (Editor && ("modes" in Editor)) {
+			document.getElementById("itsalltext").style.visibility = "hidden";
+			sourceEditor = new Editor({
+				mode: Editor.modes.css,
+				lineNumbers: true,
+				contextMenu: "orion-context"
+			});
+			var sourceEditorElement = document.getElementById("sourceeditor");
+			document.getElementById("editor").selectedIndex = 2;
+			sourceEditorType = "sourceeditor";
+			sourceEditor.appendTo(sourceEditorElement).then(init2);
+			return;
+		}
+		
+		// orion, firefox 8-26
 		var obj = {};
 		try {
 			Components.utils.import("resource:///modules/source-editor.jsm", obj);
 		} catch (ex) {
-			// orion not available, use textbox
-			init2();
-			return;
+			try {
+				// (moved circa firefox 27)
+				Components.utils.import("resource:///modules/devtools/sourceeditor/source-editor.jsm", obj);
+			} catch (ex) {
+				// orion not available
+			}
 		}
 		// check orion's pref
-		if (Services.prefs.getCharPref(obj.SourceEditor.PREFS.COMPONENT) == "textarea") {
-			init2();
-		} else {
+		if ("SourceEditor" in obj && Services.prefs.getCharPref(obj.SourceEditor.PREFS.COMPONENT) != "textarea") {
 			// use orion
-			SourceEditor = obj.SourceEditor;
+			sourceEditor = new obj.SourceEditor();
+			sourceEditorType = "orion";
 			initOrion();
+			return;
 		}
-	} else {
-		// textbox
-		init2()
 	}
+	// textbox
+	sourceEditorType = "textarea";
+	sourceEditor = codeE;
+	setTimeout(init2, 100);
 }
 
 function initStyle() {
-
 	var service = Components.classes["@userstyles.org/style;1"].getService(Components.interfaces.stylishStyle);
 
 	// See if the ID is in the URL
@@ -106,9 +128,8 @@ function initOrion() {
 		// orion and it's all text don't get along. it's all text will update display later, so let's use visibility
 		document.getElementById("itsalltext").style.visibility = "hidden";
 		
-		se = new SourceEditor();
 		var orionElement = document.getElementById("orion");
-		se.init(orionElement, {mode: SourceEditor.MODES.CSS, showLineNumbers: true, placeholderText: style.code}, init2);
+		sourceEditor.init(orionElement, {mode: sourceEditor.MODES.CSS, showLineNumbers: true}, init2);
 		document.getElementById("editor").selectedIndex = 1;
 		var appInfo = Components.classes["@mozilla.org/xre/app-info;1"].getService(Components.interfaces.nsIXULAppInfo);
 		var versionChecker = Components.classes["@mozilla.org/xpcom/version-comparator;1"].getService(Components.interfaces.nsIVersionComparator);
@@ -117,13 +138,17 @@ function initOrion() {
 			orionElement.addEventListener("keypress", handleOrionUndo, false);
 		}
 		window.controllers.insertControllerAt(0, undoController);
+		// only use our custom undo
+		document.getElementById("menu_undo").style.display = "none";
+		document.getElementById("stylish_menu_undo").style.display = "";
 }
 
 function init2() {
 
-	if (SourceEditor) {
-		se.addEventListener("ContextMenu", handleOrionContext, false);
-	} else {
+	if (sourceEditorType == "orion") {
+		sourceEditor.addEventListener("ContextMenu", handleOrionContext, false);
+	}
+	if (sourceEditorType == "textarea" || (sourceEditorType == "sourceeditor" && "setOption" in sourceEditor)) {
 		var wrapLines = prefs.getBoolPref("wrap_lines");
 		refreshWordWrap(wrapLines);
 		var wrapLinesE = document.getElementById("wrap-lines");
@@ -131,11 +156,15 @@ function init2() {
 		wrapLinesE.style.display = "";
 	}
 
+	initStyle();
+
 	setTimeout(function(){
 		// the code returned is different for some reason a little later...
 		initialCode = codeElementWrapper.value;
 		// this doesn't work till "later" either
-		codeElementWrapper.setSelectionRange(0, 0);
+		if (sourceEditorType != "sourceeditor") {
+			codeElementWrapper.setSelectionRange(0, 0);
+		}
 	},100);
 }
 
@@ -143,12 +172,12 @@ function handleOrionUndo(event) {
 	if (event.ctrlKey) {
 		if (event.which == 122 || event.which == 90) { // Z
 			if (event.shiftKey) {
-				se.redo();
+				sourceEditor.redo();
 			} else {
-				se.undo()
+				sourceEditor.undo()
 			}
 		} else if (event.which == 121 || event.which == 89) { // Y
-			se.redo();
+			sourceEditor.redo();
 		}
 	}
 }
@@ -156,13 +185,13 @@ function handleOrionUndo(event) {
 var undoController = {
 	doCommand: function(command) {
 		if (command == "stylish_cmd_undo") {
-			se.undo();
+			sourceEditor.undo();
 		}
 	},
 
 	isCommandEnabled: function(command) {
 		if (command == "stylish_cmd_undo") {
-			return se.canUndo();
+			return sourceEditor.canUndo();
 		}
 	},
 
@@ -173,56 +202,8 @@ var undoController = {
 	onEvent: function() {}
 }
 
-/*
-gEditUIVisible = false;
-function goDoCommand(a) {
-	switch (a) {
-		case "cmd_undo":
-			se.undo();
-			break;
-		case "cmd_copy":
-			se._view.invokeAction("copy");
-			break;
-		case "cmd_cut":
-			se._view.invokeAction("cut");
-			break;
-		case "cmd_paste":
-			se._view.invokeAction("paste");
-			break;
-		case "cmd_delete":
-			se._view.invokeAction("deleteNext");
-			break;
-		case "cmd_selectAll":
-			se._view.invokeAction("selectAll");
-			break;
-		default:
-			throw "Unknown command " + a;
-	}
-}
-
-function goUpdateCommand(a) {
-	if (!se) {
-		return;
-	}
-	var element = document.getElementById(a);
-	switch (a) {
-		case "cmd_undo":
-			element.setAttribute("disabled", !se.canUndo());
-			break;
-		case "cmd_copy":
-		case "cmd_cut":
-		case "cmd_delete":
-			var s = se.getSelection();
-			element.setAttribute("disabled", s.start == s.end);
-			break;
-		case "cmd_paste":
-			var t = se._view._getClipboardText();
-			element.setAttribute("disabled", t == null || t.length == 0);
-	}
-}*/
-
 function handleOrionContext(event) {
-	se.focus();
+	sourceEditor.focus();
 	goUpdateGlobalEditMenuItems();
 	goUpdateCommand("stylish_cmd_undo");
 	var menu = document.getElementById("orion-context");
@@ -354,6 +335,11 @@ function checkForErrors() {
 }
 
 function goToLine(line, col) {
+	if (sourceEditorType == "sourceeditor") {
+		codeElementWrapper.focus();
+		sourceEditor.setCursor({line: line - 1, ch: col});
+		return;
+	}
 	var index = 0;
 	var currentLine = 1;
 	while (currentLine < line) {
@@ -382,12 +368,18 @@ function insertCodeAtStart(snippet) {
 }
 
 function insertCodeAtCaret(snippet) {
-	var currentScrollTop = codeElementWrapper.scrollTop;
-	var selectionEnd = codeElementWrapper.selectionStart + snippet.length;
+	var selectionStart = codeElementWrapper.selectionStart;
+	var selectionEnd = selectionStart + snippet.length;
+	// sourceditor is good at keeping the scroll position, but others are not
+	if (sourceEditorType != "sourceeditor") {
+		var currentScrollTop = codeElementWrapper.scrollTop;
+	}
 	codeElementWrapper.value = codeElementWrapper.value.substring(0, codeElementWrapper.selectionStart) + snippet + codeElementWrapper.value.substring(codeElementWrapper.selectionEnd, codeElementWrapper.value.length);
 	codeElementWrapper.focus();
-	codeElementWrapper.scrollTop = currentScrollTop;
-	codeElementWrapper.setSelectionRange(selectionEnd, selectionEnd);
+	if (sourceEditorType != "sourceeditor") {
+		codeElementWrapper.scrollTop = currentScrollTop;
+	}
+	codeElementWrapper.setSelectionRange(selectionStart, selectionEnd);
 }
 
 function changeWordWrap(on) {
@@ -397,7 +389,11 @@ function changeWordWrap(on) {
 }
 
 function refreshWordWrap(on) {
-	codeE.setAttribute("wrap", on ? "on" : "off");
+	if (sourceEditorType == "textarea") {
+		codeE.setAttribute("wrap", on ? "on" : "off");
+	} else if (sourceEditorType == "sourceeditor") {
+		sourceEditor.setOption("lineWrapping", on);
+	}
 }
 
 function insertChromePath() {
@@ -478,48 +474,52 @@ var finder = {
 
 var codeElementWrapper = {
 	get value() {
-		if (SourceEditor) {
-			return se.getText();
+		if (sourceEditorType == "orion" || sourceEditorType == "sourceeditor") {
+			return sourceEditor.getText();
 		}
-		return codeE.value;
+		return sourceEditor.value;
 	},
 
 	set value(v) {
-		if (SourceEditor) {
-			se.setText(v);
+		if (sourceEditorType == "orion" || sourceEditorType == "sourceeditor") {
+			sourceEditor.setText(v);
 		} else {
-			codeE.value = v;
+			sourceEditor.value = v;
 		}
 	},
 
 	setSelectionRange: function(start, end) {
-		if (SourceEditor) {
-			se.setSelection(start, end);
+		if (sourceEditorType == "orion") {
+			sourceEditor.setSelection(start, end);
+		} else if (sourceEditorType == "sourceeditor") {
+			sourceEditor.setSelection(sourceEditor.getPosition(start), sourceEditor.getPosition(end));
 		} else {
-			codeE.setSelectionRange(start, end);
+			sourceEditor.setSelectionRange(start, end);
 		}
 	},
 
 	focus: function() {
-		if (SourceEditor) {
-			se.focus();
-		} else {
-			codeE.focus();
-		}
+		sourceEditor.focus();
 	},
 
 	get selectionStart() {
-		if (SourceEditor) {
-			return se.getSelection().start;
+		if (sourceEditorType == "orion") {
+			return sourceEditor.getSelection().start;
+		}
+		if (sourceEditorType == "sourceeditor") {
+			return sourceEditor.getOffset(sourceEditor.getCursor("start"));
 		}
-		return codeE.selectionStart;
+		return sourceEditor.selectionStart;
 	},
 
 	get selectionEnd() {
-		if (SourceEditor) {
-			return se.getSelection().end;
+		if (sourceEditorType == "orion") {
+			return sourceEditor.getSelection().end;
 		}
-		return codeE.selectionEnd;
+		if (sourceEditorType == "sourceeditor") {
+			return sourceEditor.getOffset(sourceEditor.getCursor("end"));
+		}
+		return sourceEditor.selectionEnd;
 	},
 
 	get scrollTop() {
@@ -531,18 +531,21 @@ var codeElementWrapper = {
 	},
 
 	get scrollElement() {
-		if (SourceEditor) {
-			return se._view._viewDiv;
+		if (sourceEditorType == "orion") {
+			return sourceEditor._view._viewDiv;
 		}
-		return codeE.inputField;
+		return sourceEditor.inputField;
 	}
 
 }
 
 window.addEventListener("load", function() {
-	var findBar = document.getElementById("findbar");
-	document.getElementById("internal-code").fastFind = finder;
-	findBar.open();
+	// sourceeditor has its own way of doing this
+	if (sourceEditorType != "sourceeditor") {
+		var findBar = document.getElementById("findbar");
+		document.getElementById("internal-code").fastFind = finder;
+		findBar.open();
+	}
 }, false);
 
 // if the style we're editing has been deleted, turn off preview and close the window
diff --git a/content/edit.xul b/content/edit.xul
index ff4bed6..3a91de7 100644
--- a/content/edit.xul
+++ b/content/edit.xul
@@ -48,7 +48,9 @@
 	</commandset>
 
 	<menupopup id="orion-context">
-		<menuitem id="stylish_menu_undo" label="&undoCmd.label;" key="key_undo" accesskey="&undoCmd.accesskey;" command="stylish_cmd_undo"/>
+		<!-- custom undo for orion -->
+		<menuitem id="stylish_menu_undo" label="&undoCmd.label;" key="key_undo" accesskey="&undoCmd.accesskey;" command="stylish_cmd_undo" style="display: none"/>
+		<menuitem id="menu_undo"/>
 		<menuseparator/>
 		<menuitem id="menu_cut"/>
 		<menuitem id="menu_copy"/>
@@ -93,6 +95,7 @@
 		<deck id="editor" flex="1">
 			<textbox id="internal-code" multiline="true" flex="1"/>
 			<hbox id="orion" flex="1"/>
+			<hbox id="sourceeditor" flex="1"/>
 		</deck>
 		<findbar id="findbar" browserid="internal-code"/>
 		<vbox id="errors" style="display:none;"/>
diff --git a/content/install.js b/content/install.js
index 9ea53f0..5a561ee 100644
--- a/content/install.js
+++ b/content/install.js
@@ -1,4 +1,4 @@
-var style, strings, name;
+var style, strings, nameElement;
 var installPingURL = null;
 var installCallback = null;
 var saved = false;
@@ -10,7 +10,7 @@ function init() {
 
 	document.documentElement.setAttribute("windowtype", window.arguments[0].windowType);
 
-	name = document.getElementById("name");
+	nameElement = document.getElementById("name");
 
 	strings = document.getElementById("strings");
 
@@ -23,7 +23,7 @@ function init() {
 	//if we don't have a name, prompt for one
 	if (style.name) {
 		//presumably someone will write a user style to edit this even if it's provided, so might as well make it work
-		name.value = style.name;
+		nameElement.value = style.name;
 		addText(intro, strings.getFormattedString("installintro", [style.name]));
 	} else {
 		document.getElementById("name-container").style.display = "";
@@ -61,11 +61,11 @@ function switchToEdit() {
 }
 
 function save(andClose) {
-	if (!name.value) {
+	if (!nameElement.value) {
 		alert(strings.getString("missingname"));
 		return false;
 	}
-	style.name = name.value;
+	style.name = nameElement.value;
 	style.enabled = true;
 	style.save();
 	if (installPingURL) {
diff --git a/content/manage-addons-fx4.xul b/content/manage-addons-fx4.xul
index a579c13..afefcc7 100644
--- a/content/manage-addons-fx4.xul
+++ b/content/manage-addons-fx4.xul
@@ -21,7 +21,7 @@
 	<vbox id="list-view">
 		<hbox id="userstyle-sorting" class="view-header" insertafter="addon-list-empty">
 			<button id="new-userstyle" label="&writenew;" oncommand="stylishCommon.addCode('')" class="addon-control"/>
-			<button id="install-from-url" label="&installfromurls;" oncommand="stylishManageAddonsFx4.startInstallFromUrls(this)" class="addon-control" style="display: none"/>
+			<button id="install-from-url" label="&installfromurls;" oncommand="stylishManageAddonsFx4.startInstallFromUrls(this)" class="addon-control"/>
 			<spacer flex="1"/>
 			<button id="userstyle-sorting-status" label="&sortenabled;" tooltiptext="&sortenabled;"
 				class="sorter" sortBy="uiState,name"
@@ -43,7 +43,7 @@
 		</hbox>
 		<hbox>
 			<button id="no-styles-write-new" position="4" label="&writenew;" oncommand="stylishCommon.addCode('')" class="addon-control"/>
-			<button id="no-styles-install-from-url" label="&installfromurls;" oncommand="stylishManageAddonsFx4.startInstallFromUrls(this)" class="addon-control" style="display: none"/>
+			<button id="no-styles-install-from-url" label="&installfromurls;" oncommand="stylishManageAddonsFx4.startInstallFromUrls(this)" class="addon-control"/>
 		</hbox>
 	</vbox>
 
diff --git a/install.rdf b/install.rdf
index fef8428..c75f420 100644
--- a/install.rdf
+++ b/install.rdf
@@ -5,7 +5,7 @@
 	<Description rdf:about="urn:mozilla:install-manifest">
 		<em:id>{46551EC9-40F0-4e47-8E18-8E5CF550CFB8}</em:id>
 		<em:name>Stylish</em:name>
-		<em:version>1.4.0</em:version>
+		<em:version>1.4.1</em:version>
 		<em:creator>Jason Barnabe</em:creator>
 		<em:homepageURL>http://userstyles.org/</em:homepageURL>
 		<em:iconURL>chrome://stylish/skin/32.png</em:iconURL>
@@ -49,6 +49,7 @@
 		<em:translator>gymka - lt</em:translator>
 		<em:translator>banthaz - sv-SE</em:translator>
 		<em:translator>kenmooda - fi</em:translator>
+		<em:translator>mdr.ksk - et-EE</em:translator>
 		<em:contributor>t1470258 - icons</em:contributor>
 		<em:contributor>LouCypher - icons</em:contributor>
 		<em:contributor>s4nji - icons</em:contributor>
@@ -58,7 +59,7 @@
 			<Description>
 				<em:id>{ec8030f7-c20a-464f-9b0e-13a3a9e97384}</em:id>
 				<em:minVersion>4.0</em:minVersion>
-				<em:maxVersion>28.0</em:maxVersion>
+				<em:maxVersion>30.0</em:maxVersion>
 			</Description>
 		</em:targetApplication>
 		<!--Thunderbird-->
@@ -66,7 +67,7 @@
 			<Description>
 				<em:id>{3550f703-e582-4d05-9a08-453d09bdfdc6}</em:id>
 				<em:minVersion>5.0</em:minVersion>
-				<em:maxVersion>28.0</em:maxVersion>
+				<em:maxVersion>30.0</em:maxVersion>
 			</Description>
 		</em:targetApplication>
 		<!--SeaMonkey-->
@@ -74,7 +75,7 @@
 			<Description>
 				<em:id>{92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a}</em:id>
 				<em:minVersion>2.1</em:minVersion>
-				<em:maxVersion>2.25</em:maxVersion>
+				<em:maxVersion>2.27</em:maxVersion>
 			</Description>
 		</em:targetApplication>
 		<!--Toolkit-->
@@ -82,7 +83,7 @@
 			<Description>
 				<em:id>toolkit at mozilla.org</em:id>
 				<em:minVersion>2.0</em:minVersion>
-				<em:maxVersion>28.0</em:maxVersion>
+				<em:maxVersion>30.0</em:maxVersion>
 			</Description>
 		</em:targetApplication>
 		<!-- Postbox -->
@@ -106,7 +107,7 @@
 			<Description>
 				<em:id>{aa3c5121-dab2-40e2-81ca-7ea25febc110}</em:id>
 				<em:minVersion>14.0</em:minVersion>
-				<em:maxVersion>28.0</em:maxVersion>
+				<em:maxVersion>30.0</em:maxVersion>
 			</Description>
 		</em:targetApplication>
 	</Description>
diff --git a/locale/et-EE/common.dtd b/locale/et-EE/common.dtd
index 30e78f1..b0a2f68 100644
--- a/locale/et-EE/common.dtd
+++ b/locale/et-EE/common.dtd
@@ -1,3 +1,3 @@
-<!ENTITY editstyle "Redigeerimine">
-<!ENTITY editstyle.ak "E">
+<!ENTITY editstyle "Redigeeri">
+<!ENTITY editstyle.ak "R">
 <!ENTITY stylish "Stylish">
diff --git a/locale/et-EE/common.properties b/locale/et-EE/common.properties
index 0f36105..66a46ce 100644
--- a/locale/et-EE/common.properties
+++ b/locale/et-EE/common.properties
@@ -1,10 +1,10 @@
-changeTags=Eemalda silt \'%S\' ja lisa sildid
-changeTagsNoCurrent=Lisa sildid
-changeTagsTitle=Muuda silte
-deleteStyle=Oled kindel, et soovid desinstallida \'%s\'?
-deleteStyleTitle=Desinstalleeri stiil?
-deleteStyleOK=desinstall
-deleteStyles=Oled kindel, et soovid need %S stiilid kustutada?
-deleteStylesTitle=kustuta stiilid?
-deleteStylesOK=Desinstall
-extensions.{46551EC9-40F0-4e47-8E18-8E5CF550CFB8}.description=Muuda veebilehe stiili Stylishiga, kasuta stiili mänedžer
+changeTags=Eemalda silt \'%S\' ja lisa järgnevad sildid:
+changeTagsNoCurrent=Lisa järgnevad sildid:
+changeTagsTitle=Siltide muutmine
+deleteStyle=Kas oled kindel, et soovid stiili \'%s\' kustutada?
+deleteStyleTitle=Kas stiil kustutada?
+deleteStyleOK=Kustuta
+deleteStyles=Kas oled kindel, et soovid need %S stiili kustutada?
+deleteStylesTitle=Kas stiilid kustutada?
+deleteStylesOK=Kustuta
+extensions.{46551EC9-40F0-4e47-8E18-8E5CF550CFB8}.description=Muuda veebi stiili kasutaja stiilide halduriga Stylishiga.
diff --git a/locale/et-EE/domi.dtd b/locale/et-EE/domi.dtd
index 0745cc8..acf5beb 100644
--- a/locale/et-EE/domi.dtd
+++ b/locale/et-EE/domi.dtd
@@ -1 +1 @@
-<!ENTITY copyselector "Kopeeri selekteerija">
+<!ENTITY copyselector "Kopeeri selektor">
diff --git a/locale/et-EE/edit.dtd b/locale/et-EE/edit.dtd
index 20edbd2..73af378 100644
--- a/locale/et-EE/edit.dtd
+++ b/locale/et-EE/edit.dtd
@@ -1,24 +1,24 @@
 <!ENTITY chromefolder "Chrome kausta asukoht">
 <!ENTITY chromefolder.ak "C">
-<!ENTITY dataURI "teabe URI...">
+<!ENTITY dataURI "Andmete URI...">
 <!ENTITY dataURI.ak "D">
-<!ENTITY htmlnamespace "HTML nimekoht vaikevalikuna">
+<!ENTITY htmlnamespace "HTML nimeruum vaikeväärtusega">
 <!ENTITY htmlnamespace.ak "H">
 <!ENTITY insert "Sisesta">
-<!ENTITY insert.ak "I">
+<!ENTITY insert.ak "T">
 <!ENTITY name "Nimi">
 <!ENTITY name.ak "N">
-<!ENTITY openintexternaleditor "Ava eraldi redigeerijas">
-<!ENTITY openintexternaleditor.ak "O">
+<!ENTITY openintexternaleditor "Ava eraldi redaktoris">
+<!ENTITY openintexternaleditor.ak "V">
 <!ENTITY preview "Eelvaade">
-<!ENTITY preview.ak "P">
+<!ENTITY preview.ak "E">
 <!ENTITY save "Salvesta">
 <!ENTITY save.ak "S">
-<!ENTITY switchtoinstall "vaheta installile">
-<!ENTITY switchtoinstall.ak "I">
+<!ENTITY switchtoinstall "Lülitu installimisvaatele">
+<!ENTITY switchtoinstall.ak "L">
 <!ENTITY tags "Sildid">
-<!ENTITY tags.ak "T">
-<!ENTITY wraplines "murra read">
-<!ENTITY wraplines.ak "W">
-<!ENTITY xulnamespace "XUL nimekoht vaikavalikuna">
+<!ENTITY tags.ak "d">
+<!ENTITY wraplines "Murra pikad read">
+<!ENTITY wraplines.ak "M">
+<!ENTITY xulnamespace "XUL nimeruum vaikeväärtusega">
 <!ENTITY xulnamespace.ak "X">
diff --git a/locale/et-EE/edit.properties b/locale/et-EE/edit.properties
index 2f6e3ec..f617dda 100644
--- a/locale/et-EE/edit.properties
+++ b/locale/et-EE/edit.properties
@@ -1,7 +1,7 @@
-dataURIDialogTitle=Vali fail sisestuseks
-editstyletitle=\'%S\' muutmas
+dataURIDialogTitle=Vali fail, mis sisestada
+editstyletitle=Stiili \'%S\' muutmine
 newstyletitle=Uus stiil
-missingcode=Lisa kood selle stiili jaoks
+missingcode=Sisesta sellele stiilile natuke koodi.
 missingname=Anna stiilile nimi.
-unsavedchanges=Would you like to save your changes to this style?
-unsavedchangestitle=Save changes?
+unsavedchanges=Kas soovid sellele stiilile tehtud muudatused salvestada?
+unsavedchangestitle=Kas muudatused salvestada?
diff --git a/locale/et-EE/extensions.dtd b/locale/et-EE/extensions.dtd
index e8584f5..937604b 100644
--- a/locale/et-EE/extensions.dtd
+++ b/locale/et-EE/extensions.dtd
@@ -16,9 +16,9 @@
 <!-- Command Bar items -->
 <!ENTITY cmd.checkUpdatesAll.label "Otsi uuendusi">
 <!ENTITY cmd.checkUpdatesAll.accesskey "O">
-<!ENTITY cmd.checkUpdatesAllAddon.tooltip "Otsi uuendusi lisadele">
-<!ENTITY cmd.checkUpdatesAllTheme.tooltip "Otsi uuendusi teemadele">
-<!ENTITY cmd.checkUpdatesAllPlugin.tooltip "Otsi uuendusi pluginatele">
+<!ENTITY cmd.checkUpdatesAllAddon.tooltip "Otsi lisadele uuendusi">
+<!ENTITY cmd.checkUpdatesAllTheme.tooltip "Otsi teemadele uuendusi">
+<!ENTITY cmd.checkUpdatesAllPlugin.tooltip "Otsi pluginatele uuendusi">
 <!ENTITY cmd.installLocalFile.label "Paigalda...">
 <!ENTITY cmd.installLocalFile.accesskey "i">
 <!ENTITY cmd.installFileAddon.tooltip "Paigalda lisa">
@@ -28,13 +28,13 @@
 <!ENTITY cmd.installUpdatesAll2.tooltip "Paigalda valitud uuendused">
 <!ENTITY cmd.restartApp2.label "Taaskäivita &brandShortName;">
 <!ENTITY cmd.restartApp2.accesskey "T">
-<!ENTITY cmd.restartApp2.tooltip "Paigalduse lõpetamiseks taaskäivita &brandShortName;">
+<!ENTITY cmd.restartApp2.tooltip "Muudatuste rakendamiseks taaskäivita &brandShortName;">
 <!ENTITY cmd.skip.label "Jäta vahele">
 <!ENTITY cmd.skip.accesskey "J">
 <!ENTITY cmd.skip.tooltip "Jäta need uuendused vahele">
 <!ENTITY cmd.continue.label "Jätka">
 <!ENTITY cmd.continue.accesskey "t">
-<!ENTITY cmd.continue.tooltip "Jätka &brandShortName;\'i laadimist">
+<!ENTITY cmd.continue.tooltip "Jätka &brandShortName;i laadimist">
 <!ENTITY cmd.enableAll.label "Luba kõik">
 <!ENTITY cmd.enableAll.accesskey "k">
 <!ENTITY cmd.enableAll.tooltip "Luba kõik kuvatud lisad">
@@ -44,22 +44,22 @@
 <!-- Displayed in the selected Add-on\'s richlistitem and context menu -->
 <!ENTITY cmd.useTheme.label "Kasuta teemat">
 <!ENTITY cmd.useTheme.accesskey "t">
-<!ENTITY cmd.useTheme.tooltip "Muudab &brandShortName;\'i teemat">
+<!ENTITY cmd.useTheme.tooltip "Muudab &brandShortName;i teemat">
 <!ENTITY cmd.options.label "Sätted">
 <!ENTITY cmd.options.accesskey "S">
-<!ENTITY cmd.options.tooltip "Muuda valitud laienduse omadusi">
+<!ENTITY cmd.options.tooltip "Muuda valitud laienduse sätteid">
 <!ENTITY cmd.optionsUnix.label "Eelistused">
 <!ENTITY cmd.optionsUnix.accesskey "E">
 <!ENTITY cmd.optionsUnix.tooltip "Muuda valitud laienduse eelistusi">
 <!ENTITY cmd.enable.label "Luba">
 <!ENTITY cmd.enable.accesskey "L">
-<!ENTITY cmd.enable.tooltip "Luba see lisa, kui &brandShortName; on taaskäivitatud">
+<!ENTITY cmd.enable.tooltip "Luba see lisa &brandShortName;i taaskäivitamisel">
 <!ENTITY cmd.disable.label "Keela">
 <!ENTITY cmd.disable.accesskey "K">
-<!ENTITY cmd.disable.tooltip "Keela see lisa, kui &brandShortName; on taaskäivitatud">
+<!ENTITY cmd.disable.tooltip "Keela see lisa &brandShortName;i taaskäivitamisel">
 <!ENTITY cmd.uninstall.label "Eemalda">
 <!ENTITY cmd.uninstall2.accesskey "E">
-<!ENTITY cmd.uninstall2.tooltip "Eemalda see lisa, kui &brandShortName; on taaskäivitatud">
+<!ENTITY cmd.uninstall2.tooltip "Eemalda see lisa &brandShortName;i taaskäivitamisel">
 <!ENTITY cmd.cancelUninstall.label "Loobu eemaldamisest">
 <!ENTITY cmd.cancelUninstall.accesskey "L">
 <!ENTITY cmd.cancelUninstall.tooltip "Loobu selle lisa eemaldamisest">
@@ -110,7 +110,7 @@
 <!ENTITY toBeEnabled.label "See lisa lubatakse &brandShortName;i taaskäivitamisel.">
 <!ENTITY toBeInstalled.label "See lisa paigaldatakse &brandShortName;i taaskäivitamisel.">
 <!ENTITY toBeUninstalled.label "See lisa eemaldatakse &brandShortName;i taaskäivitamisel.">
-<!ENTITY toBeUpdated.label "Seda lisa uuendatakse, kui &brandShortName; on taaskäivitatud.">
+<!ENTITY toBeUpdated.label "See lisa uuendatakse &brandShortName;i taaskäivitamisel.">
 <!ENTITY getExtensions.label "Hangi laiendusi">
 <!ENTITY getThemes.label "Hangi teemasid">
 <!ENTITY getPlugins.label "Hangi pluginaid">
@@ -145,7 +145,7 @@
 <!ENTITY infoUpdateInfoError.label "Uuenduse lisainfo laadimisel esines viga">
 <!ENTITY updateSuccess.label "Uuendamine edukalt lõpetatud.">
 <!ENTITY installSuccess.label "Paigaldamine edukalt lõpetatud.">
-<!ENTITY installSuccessRestart.label "Paigalduse lõpetamiseks taaskäivita &brandShortName;">
+<!ENTITY installSuccessRestart.label "Paigalduse lõpetamiseks taaskäivita &brandShortName;.">
 <!ENTITY updateSuccessRestart.label "Uuendamise lõpetamiseks taaskäivita &brandShortName;.">
 <!ENTITY installWaiting.label "Ootamine...">
 <!ENTITY installIncompatibleUpdate.label "Ühilduvuse kontrollimine...">
diff --git a/locale/et-EE/install.dtd b/locale/et-EE/install.dtd
index 9977ad5..220f0eb 100644
--- a/locale/et-EE/install.dtd
+++ b/locale/et-EE/install.dtd
@@ -1,8 +1,8 @@
-<!ENTITY entername "Anna sellele stiilile nimi">
-<!ENTITY install "Install">
+<!ENTITY entername "Anna sellele stiilile nimi:">
+<!ENTITY install "Installi">
 <!ENTITY install.ak "I">
 <!ENTITY preview "Eelvaade">
-<!ENTITY preview.ak "P">
-<!ENTITY switchtoedit "vali redigeerimine">
-<!ENTITY switchtoedit.ak "E">
-<!ENTITY title "Installeeri kasutaja stiil">
+<!ENTITY preview.ak "E">
+<!ENTITY switchtoedit "Lülitu muutmisvaatele">
+<!ENTITY switchtoedit.ak "L">
+<!ENTITY title "Kasutaja stiili installimine">
diff --git a/locale/et-EE/install.properties b/locale/et-EE/install.properties
index 713de08..8aff38b 100644
--- a/locale/et-EE/install.properties
+++ b/locale/et-EE/install.properties
@@ -1,8 +1,8 @@
-installintro=Sa oled \'%S\' installimas
-installintrononame=Sa oled uut stiili installimas
-installapp=See stiil võib mõjutada %S kasutajat. Sa võid vajada restarti %S et see stiil saaks rakenduda
-installglobal=See stiil võib muuta kõiki veebilehti.
-installsite=See stiil võib muuta järgnevaid veebilehti :
-installnotype=See stiil võib muuta veebilehti või %S kasutajat
-missingname=Anna sellele stiilile nimi
-preview.tooltip=Ajutiselt rakendatakse see stiil, et näha kas see meeldib sulle.
+installintro=Sa oled Stylishiga installimas stiili \'%S\'.
+installintrononame=Sa oled Stylishiga installimas uut stiili.
+installapp=See stiil võib mõjutada %Si kasutajaliidest. Selle stiili kasutamiseks võib olla vajalik %Si taaskäivitamine.
+installglobal=See stiil võib mõjutada kõiki veebilehti.
+installsite=See stiil võib mõjutada järgnevaid veebilehti:
+installnotype=See stiil võib mõjutada veebilehti või %Si kasutajaliidest.
+missingname=Anna sellele stiilile nimi.
+preview.tooltip=See stiil rakendatakse ajutiselt, et saaksid vaadata, kas see sulle meeldib.
diff --git a/locale/et-EE/manage.dtd b/locale/et-EE/manage.dtd
index 4289351..b2db7c7 100644
--- a/locale/et-EE/manage.dtd
+++ b/locale/et-EE/manage.dtd
@@ -1,19 +1,19 @@
 <!ENTITY changetags "Muuda silte">
-<!ENTITY changetags.ak "C">
+<!ENTITY changetags.ak "M">
 <!ENTITY done "Valmis">
-<!ENTITY done.ak "D">
+<!ENTITY done.ak "V">
 <!ENTITY filter "Otsi">
-<!ENTITY installfromurls "Install from URLs...">
+<!ENTITY installfromurls "Installi URL-ilt...">
 <!ENTITY manageaddonstitle "Kasutaja stiilid">
 <!ENTITY managetitle "Stylish">
-<!ENTITY nostylesstart "Külasta">
-<!ENTITY nostylesend "informatsiooniks, kuidas kasutada Stylishi">
+<!ENTITY nostylesstart "Stylishi kasutamise kohta lähema teabe saamiseks mine lehele">
+<!ENTITY nostylesend ".">
 <!ENTITY sortenabled "Lubatud">
 <!ENTITY sortname "Nimi">
 <!ENTITY sorttag "Silt">
 <!ENTITY sorttype "Tüüp">
-<!ENTITY sortgroup "Sorteeri:">
+<!ENTITY sortgroup "Sorteerimisalus:">
 <!ENTITY update "Uuendus">
 <!ENTITY update.ak "U">
-<!ENTITY writenew "kirjuta uus stiil">
-<!ENTITY writenew.ak "W">
+<!ENTITY writenew "Kirjuta uus stiil">
+<!ENTITY writenew.ak "K">
diff --git a/locale/et-EE/manage.properties b/locale/et-EE/manage.properties
index 6d02f16..73c2e0a 100644
--- a/locale/et-EE/manage.properties
+++ b/locale/et-EE/manage.properties
@@ -1,24 +1,24 @@
 groupEnabledTrue=Lubatud
 groupEnabledFalse=Keelatud
-groupTagNone=Pole silte
+groupTagNone=Silte pole
 groupTypeApp=Rakendus
 groupTypeGlobal=Globaalne
-groupTypeNone=Pole tüüpi
+groupTypeNone=Tüüpi pole
 groupTypeSite=Lehekülg
-styleRegistrationOff=kõik stiilid on välja lülitatud.
+styleRegistrationOff=Kõik stiilid on välja lülitatud.
 styleRegistrationTurnOn=Lülita stiilid sisse
 styleRegistrationTurnOn.ak=T
-updateAvailable=Uuendus on saadaval
-updateCheckError=Tekkis häire uuenduste otsimisel.
-updateCompleted=Uuendamine edukalt lõpetatud
-updateFailed=Uuendamine ebaõnnestus
-updateNotFound=No updates found.
-updateNotPossible=Uuendamine pole võimalik
-appstyledescription=Affects the user interface.
-globalstyledescription=Can affect anything.
-sitestyledescription=Affects %S.
-tagstyledescription=Tags: %S.
+updateAvailable=Uuendus on saadaval.
+updateCheckError=Uuenduste otsimisel tekkis viga.
+updateCompleted=Uuendamine edukalt lõpetatud.
+updateFailed=Uuendamine ebaõnnestus.
+updateNotFound=Uuendusi ei leitud.
+updateNotPossible=Uuendamine pole võimalik.
+appstyledescription=Mõjutab kasutajaliidest.
+globalstyledescription=Võib mõjutada kõike
+sitestyledescription=Mõjutab: %S.
+tagstyledescription=Sildid: %S.
 manageaddonstitle=Kasutaja stiilid
-installfromurlsprompttitle=Install from URLs
-installfromurlsprompt=Enter URLs of user styles to install. These can be pages on userstyles.org or CSS files. Separate multiple URLs by spaces.
-installfromurlserror=Could not install from the following URLs: %s.
+installfromurlsprompttitle=URL-ilt installimine
+installfromurlsprompt=Sisesta installitava stiilide URL-id. Need võivad olla lehed saidil userstyles.org või CSS failid. Eralda URL-id tühikuga.
+installfromurlserror=Ei saanud järgmistelt URL-idelt installida: %s.
diff --git a/locale/et-EE/overlay.dtd b/locale/et-EE/overlay.dtd
index e9438e8..a4dc4cf 100644
--- a/locale/et-EE/overlay.dtd
+++ b/locale/et-EE/overlay.dtd
@@ -1,12 +1,12 @@
-<!ENTITY addfile "Installi fail ...">
+<!ENTITY addfile "Installi fail...">
 <!ENTITY addfile.ak "I">
 <!ENTITY findstylebrowser "Leia stiile sellele lehele">
-<!ENTITY findstylebrowser.ak "F">
-<!ENTITY managestyles "korralda stiile ...">
-<!ENTITY managestyles.ak "M">
-<!ENTITY turnon "Lülita kõik stiilid sisse.">
-<!ENTITY turnon.ak "T">
+<!ENTITY findstylebrowser.ak "L">
+<!ENTITY managestyles "Halda stiile...">
+<!ENTITY managestyles.ak "H">
+<!ENTITY turnon "Lülita kõik stiilid sisse">
+<!ENTITY turnon.ak "A">
 <!ENTITY turnoff "Lülita kõik stiilid välja">
-<!ENTITY turnoff.ak "T">
+<!ENTITY turnoff.ak "A">
 <!ENTITY writestyle "Kirjuta uus stiil">
-<!ENTITY writestyle.ak "W">
+<!ENTITY writestyle.ak "K">
diff --git a/locale/et-EE/overlay.properties b/locale/et-EE/overlay.properties
index c21eb16..778ac73 100644
--- a/locale/et-EE/overlay.properties
+++ b/locale/et-EE/overlay.properties
@@ -1,10 +1,10 @@
-tooltip=Stylish - %S lehe stiil(id), %S globaalne(sed) stiil(id)
-tooltipStylesOff=Sylish - Stiilid on väljas
-updatestyle=Oled kindel, et soovid uuendada \'%S\'?
-updatestyleok=Uuendus
-updatestyletitle=Uuenda stiili
-writeblank=Tühi stiil ...
-writeblankaccesskey=B
-writefordomain=%S jaoks...
-writeforsite=Sellele URLile ...
+tooltip=Stylish - %S lehe stiil(i), %S globaalne(set) stiil(i)
+tooltipStylesOff=Stylish - Stiilid on välja lülitatud
+updatestyle=Kas oled kindel, et soovid stiili \'%S\' uuendada?
+updatestyleok=Uuenda
+updatestyletitle=Stiili uuendamine
+writeblank=Tühi stiil...
+writeblankaccesskey=T
+writefordomain=Lehele %S...
+writeforsite=Sellele URLile...
 writeforsiteaccesskey=U
diff --git a/skin/manage-addons-fx11.css b/skin/manage-addons-fx11.css
index e5c6dad..7b24c4a 100644
--- a/skin/manage-addons-fx11.css
+++ b/skin/manage-addons-fx11.css
@@ -1,3 +1,7 @@
 #install-from-url, #no-styles-install-from-url {
-	display: -moz-box !important;
+	display: none;
+}
+/* Show buttons only when userstyle category is the active view */
+#list-view[type="userstyle"] :-moz-any(#install-from-url, #no-styles-install-from-url) {
+	display: -moz-box;
 }

diff --git a/components/stylishStyle.js b/components/stylishStyle.js
index b5b1dda..f442935 100644
--- a/components/stylishStyle.js
+++ b/components/stylishStyle.js
@@ -6,7 +6,7 @@ function Style() {
 	this.idUrl = null;
 	this.updateUrl = null;
 	this.md5Url = null;
-	this.appliedUrl = null;
+	this.appliedInfo = null;
 	this.lastSavedCode = null;
 	this.applyBackgroundUpdates = null;
 	this.mode = this.CALCULATE_META | this.REGISTER_STYLE_ON_CHANGE;
@@ -20,8 +20,7 @@ function Style() {
  
 
 	this.previewOn = false;
-	//whether the applied url is yet to be calculated
-	this.appliedUrlToBeCalculated = false;
+	this.appliedInfoToBeCalculated = false;
 }
 Style.prototype = {
 
@@ -158,8 +157,8 @@ Style.prototype = {
 	},
 
 	set name(name) {
-		//reference appliedUrl to make sure it has been calculated before we change the name
-		this.appliedUrl;
+		//reference appliedInfo to make sure it has been calculated before we change the name
+		this.appliedInfo;
 		this._name = name;
 	},
 
@@ -677,21 +676,32 @@ Style.prototype = {
 		var dataUrl = this.dataUrl;
 		if (!dataUrl)
 			return;
-		this.appliedUrl = dataUrl;
-		this.sss.loadAndRegisterSheet(this.appliedUrl, this.sss.AGENT_SHEET);
+		var registrationMethod = this.calculateRegistrationMethod();
+		// Save what we applied so we know what to remove later
+		this.appliedInfo = [dataUrl, registrationMethod];
+		this.sss.loadAndRegisterSheet(dataUrl, registrationMethod);
 	},
 
 	unregister: function() {
-		var unregisterUrl = this.shouldUnregisterOnLoad() ? this.dataUrl : this.appliedUrl;
-		if (unregisterUrl == null) {
+		var unregisterUrl;
+		var unregisterMethod;
+		if (this.shouldUnregisterOnLoad()) {
+			unregisterUrl = this.dataUrl;
+			unregisterMethod = this.calculateRegistrationMethod();
+		} else if (this.appliedInfo == null) {
+			// not registered in the first place
 			return;
+		} else {
+			unregisterUrl = this.appliedInfo[0];
+			unregisterMethod = this.appliedInfo[1];
 		}
-		if (this.sss.sheetRegistered(unregisterUrl, this.sss.AGENT_SHEET))
-			this.sss.unregisterSheet(unregisterUrl, this.sss.AGENT_SHEET);
+		
+		if (this.sss.sheetRegistered(unregisterUrl, unregisterMethod))
+			this.sss.unregisterSheet(unregisterUrl, unregisterMethod);
 		// ignore unregistered styles if stylish isn't on
 		else if (this.stylishOn)
 			Components.utils.reportError("Stylesheet is supposed to be unregistered, but it's not registered in the first place.");
-		this.appliedUrl = null;
+		this.appliedInfo = null;
 	},
 
 	bind: function(statement, name, value) {
@@ -745,16 +755,16 @@ Style.prototype = {
 		}
 	},
 
-	get appliedUrl() {
-		if (this.appliedUrlToBeCalculated) {
-			this.appliedUrl = this.dataUrl;
-			this.appliedUrlToBeCalculated = false;
+	get appliedInfo() {
+		if (this.appliedInfoToBeCalculated) {
+			this.appliedInfo = [this.dataUrl, this.calculateRegistrationMethod()];
+			this.appliedInfoToBeCalculated = false;
 		}
-		return this._appliedUrl;
+		return this._appliedInfo;
 	},
 
-	set appliedUrl(url) {
-		this._appliedUrl = url;
+	set appliedInfo(info) {
+		this._appliedInfo = info;
 	},
 
 	findSql: function(sql, parameters, mode, connection) {
@@ -838,8 +848,8 @@ Style.prototype = {
 	},
 
 	setCode: function(code, shouldRegister) {
-		//reference appliedUrl to make sure it has been calculated before we change the code
-		this.appliedUrl;
+		//reference appliedInfo to make sure it has been calculated before we change the code
+		this.appliedInfo;
 		//save the last saved code in case we have to revert
 		if (!this.lastSavedCode && this.code && this.id)
 			this.lastSavedCode = this.code;
@@ -861,7 +871,7 @@ Style.prototype = {
 		this.originalCode = originalCode;
 		this.setCode(code, shouldRegister);
 		if (!shouldRegister && this.enabled) {
-			this.appliedUrlToBeCalculated = true;
+			this.appliedInfoToBeCalculated = true;
 		}
 		if (this.shouldUnregisterOnLoad()) {
 			this.unregister();
@@ -956,6 +966,14 @@ Style.prototype = {
 
 	unescapeRegexLiterals: function(s) {
 		return s.replace(/\\/g, "");
+	},
+
+	calculateRegistrationMethod: function() {
+		// Default to AUTHOR_SHEET if available, AGENT_SHEET if not or specifically chosen with a comment like /* AGENT_SHEET */
+		if (!("AUTHOR_SHEET" in this.sss) || /\/\*\s*AGENT_SHEET\s*\*\//.test(this.code)) {
+			return this.sss.AGENT_SHEET;
+		}
+		return this.sss.AUTHOR_SHEET;
 	}
 
 };
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/stylish.git



More information about the Pkg-mozext-commits mailing list